@@ -1,9 +1,9 @@
 from pathlib import Path
-from typing import Any, List, Mapping, Optional
+from typing import Any, DefaultDict, List, Optional
 
 from datamodel_code_generator.imports import Import
-from datamodel_code_generator.model import DataModel, DataModelField
-from datamodel_code_generator.model.pydantic.types import get_data_type, type_map
+from datamodel_code_generator.model import DataModel, DataModelFieldBase
+from datamodel_code_generator.model.pydantic.types import get_data_type
 from datamodel_code_generator.types import DataType, Types
 
 
@@ -13,12 +13,12 @@ class DataClass(DataModel):
     def __init__(
         self,
         name: str,
-        fields: List[DataModelField],
+        fields: List[DataModelFieldBase],
         decorators: Optional[List[str]] = None,
         base_classes: Optional[List[str]] = None,
         custom_base_class: Optional[str] = None,
         custom_template_dir: Optional[Path] = None,
-        extra_template_data: Optional[Mapping[str, Any]] = None,
+        extra_template_data: Optional[DefaultDict[str, Any]] = None,
         auto_import: bool = True,
         reference_classes: Optional[List[str]] = None,
     ):
