@@ -22,4 +22,4 @@ class OpenAPIParser(JsonSchemaParser):
         for obj_name, raw_obj in components[
             'schemas'
         ].items():  # type: str, Dict[Any, Any]
-            self.parse_raw_obj(obj_name, raw_obj, ['#/components', 'schema', obj_name])
+            self.parse_raw_obj(obj_name, raw_obj, ['#/components', 'schemas', obj_name])
